@@ -21,7 +21,9 @@ def load_from_hub(repo_id: str, filename: str) -> str:
       model_download_url = hf_hub_url(repo_id=repo_id,
                                  filename=filename)
       # Downloading and caching the model on your local disk
-      downloaded_model_file = cached_download(model_download_url)
+      downloaded_model_file = cached_download(model_download_url,
+                                             library_name="huggingface-sb3",
+                                             library_version="1.0.7")
     
     # TODO: I need to find a way to override the HTTPError with mine
     except HTTPError:
@@ -30,4 +32,4 @@ def load_from_hub(repo_id: str, filename: str) -> str:
           f"1. That your repository exists https://huggingface.co/{repo_id} \n"
           f"2. That the filename you want to retrieve is the correct one and is a .zip file"
       )
-    return downloaded_model_file
\ No newline at end of file
+    return downloaded_model_file
